pub struct Word {
pub word: String,
pub language_english_name: String,
pub word_type: String,
}Fields
word: StringThe word itself.
Multiple Words may have the same word if they are of a different language or type.
language_english_name: StringThe english name of the language this word is from. While different languages may contain the same words, there will be a separate word instance for each.
word_type: StringThe word type, as declared by wiktionary. While a word may have multiple types, there will be a separate word instance for each.